#
# Product:   Macal
# Author:    Marco Caspers
# Date:      07-09-2022
#

__version__ = '4.0.77'
__author__ = 'Marco Caspers'
__author_email__ = 'SamaDevTeam@westcon.com'
__credits__      = """Source used:
   "The Dragon Book": Compilers: Principles, Techniques, and Tools"""